Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(337)

Unified Diff: remoting/host/desktop_process.h

Issue 2446053002: Use ChannelMojo between the remoting daemon and desktop processes. (Closed)
Patch Set: Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | remoting/host/desktop_process.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/desktop_process.h
diff --git a/remoting/host/desktop_process.h b/remoting/host/desktop_process.h
index ec3f87ee5ef969712aac874499b2e2c572cdc1af..4f0546e046a673c96b091e9e04caaf4101c8a91d 100644
--- a/remoting/host/desktop_process.h
+++ b/remoting/host/desktop_process.h
@@ -16,6 +16,7 @@
#include "base/memory/ref_counted.h"
#include "base/memory/weak_ptr.h"
#include "ipc/ipc_listener.h"
+#include "mojo/public/cpp/system/message_pipe.h"
#include "remoting/host/desktop_session_agent.h"
namespace IPC {
@@ -33,10 +34,10 @@ class DesktopProcess : public DesktopSessionAgent::Delegate,
public IPC::Listener,
public base::SupportsWeakPtr<DesktopProcess> {
public:
- DesktopProcess(
- scoped_refptr<AutoThreadTaskRunner> caller_task_runner,
- scoped_refptr<AutoThreadTaskRunner> input_task_runner,
- const std::string& daemon_channel_name);
+ DesktopProcess(scoped_refptr<AutoThreadTaskRunner> caller_task_runner,
+ scoped_refptr<AutoThreadTaskRunner> input_task_runner,
+ scoped_refptr<AutoThreadTaskRunner> io_task_runner,
+ mojo::ScopedMessagePipeHandle daemon_channel_handle);
~DesktopProcess() override;
// DesktopSessionAgent::Delegate implementation.
@@ -73,12 +74,15 @@ class DesktopProcess : public DesktopSessionAgent::Delegate,
// Used to run input-related tasks.
scoped_refptr<AutoThreadTaskRunner> input_task_runner_;
+ // Used for IPC communication with Daemon process.
+ scoped_refptr<AutoThreadTaskRunner> io_task_runner_;
+
// Factory used to create integration components for use by |desktop_agent_|.
std::unique_ptr<DesktopEnvironmentFactory> desktop_environment_factory_;
// Name of the IPC channel connecting the desktop process with the daemon
// process.
- std::string daemon_channel_name_;
+ mojo::ScopedMessagePipeHandle daemon_channel_handle_;
// IPC channel connecting the desktop process with the daemon process.
std::unique_ptr<IPC::ChannelProxy> daemon_channel_;
« no previous file with comments | « no previous file | remoting/host/desktop_process.cc » ('j') | no next file with comments »
@@ -73,12 +74,15 @@ class DesktopProcess : public DesktopSessionAgent::Delegate,
// Factory used to create integration components for use by |desktop_agent_|.
std::unique_ptr<DesktopEnvironmentFactory> desktop_environment_factory_;
- // Name of the IPC channel connecting the desktop process with the daemon
+ // Handle for the IPC channel connecting the desktop process with the daemon
// process.

Powered by Google App Engine
This is Rietveld 408576698